
# coding: utf-8

# In[8]:

#this code file adds the beta-carotene pathway and export as a new model
from cameo import load_model

model_bc = load_model ("E:\IGEM\Bioinformatics\gsm\model_yl\MODEL1508190002_mathias.xml")


# In[9]:

#define uptake rates of C source and O2
model_bc.reactions.get_by_id('1808').lower_bound = 0 #glycerol uptake
model_bc.reactions.get_by_id('1714').lower_bound = -20 # glucose uptake rate 
model_bc.reactions.get_by_id('1714').upper_bound = -20 # glucose uptake rate 
model_bc.reactions.get_by_id('1992').lower_bound = -20 #oxygen uptake rate
model_bc.reactions.get_by_id('1992').lower_bound = -20 #oxygen uptake rate
model_bc.reactions.get_by_id('1634').upper_bound = 0 #acetate exchange


# In[10]:

# Add metabolites to model
from cobra import Metabolite, Reaction
met1 = Metabolite('phytoene',name='phytoene',compartment='cy')
met2 = Metabolite('neurosporene',name='neurosporene',compartment='cy')
met3 = Metabolite('lycopene',name='lycopene',compartment='cy')
met4 = Metabolite('bcarotene',name='beta_carotene',compartment='cy')

# New pointers to involved metabolites
met0 = model_bc.metabolites.get_by_id("m513")
metPP = model_bc.metabolites.get_by_id("m203")
metH = model_bc.metabolites.get_by_id("m10")
metFAD = model_bc.metabolites.get_by_id("m528")
metNADP = model_bc.metabolites.get_by_id("m41")
metGlycerol = model_bc.metabolites.get_by_id("m277")

# New pointers to involved reactions
reacGlyTr = model_bc.reactions.get_by_id("1171")
reacO2Tr = model_bc.reactions.get_by_id("1979")

# Add reactions to model
reac1 = Reaction('phytoeneSynthase')
reac1.name = 'phytoene synthase'
reac1.add_metabolites({met0: -2.0, met1: 1.0, metPP: 2.0, metH: 2.0})
reac1.reversibility = 1
reac1.lower_bound = -1000
reac1.gene_reaction_rule = 'crtYB'

reac2 = Reaction('caroteneDesaturaseStep1')
reac2.name = 'carotene desaturase step 1'
reac2.add_metabolites({met1: -1.0,  met2: 1.0, metH: 6.0})
reac2.reversibility = 1
reac2.lower_bound = -1000
reac2.gene_reaction_rule = 'crtI'

reac3 = Reaction('caroteneDesturaseStep2')
reac3.name = 'carotene desaturase step 2'
reac3.add_metabolites({met2: -1.0,  met3: 1.0, metH: 2.0})
reac3.reversibility = 1
reac3.lower_bound = -1000
reac3.gene_reaction_rule = 'crtI'

reac4 = Reaction('lycopeneCyslase')
reac4.name = 'lycopene cyclase'
reac4.add_metabolites({met3: -1.0, met4: 1.0, metH: 2.0})
reac4.reversibility = 1
reac4.lower_bound = -1000
reac4.gene_reaction_rule = 'crtYB'


model_bc.add_reaction(reac1)
model_bc.add_reaction(reac2)
model_bc.add_reaction(reac3)
model_bc.add_reaction(reac4)


# In[11]:

model_bc.reactions.lycopeneCyslase.check_mass_balance()


# In[5]:

model_bc.change_objective('2111')
print ('gerger', model_bc.solve().fluxes['lycopeneCyslase'])
print('growth', model_bc.solve().fluxes['2111'])


# In[12]:

model_bc.add_demand(model_bc.metabolites.bcarotene)
model_bc.add_demand(model_bc.metabolites.lycopene)


# In[107]:

model_bc.metabolites.bcarotene


# In[13]:

import cobra
cobra.io.write_sbml_model(model_bc, "E:\IGEM\Bioinformatics\gsm\model_yl\MODEL1508190002_bc2g.xml")


# In[ ]:



